@@ -3,7 +3,7 @@ TOKEN_URL = "https://cms.lamarzocco.io/oauth/v2/token"
 CUSTOMER_URL = "https://cms.lamarzocco.io/api/customer"
 GW_MACHINE_BASE_URL = "https://gw.lamarzocco.io/v1/home/machines"
 
-POLLING_DELAY_S = 10
+POLLING_DELAY_S = 20
 
 MODEL_LMU = "Micra"
 
@@ -23,4 +23,6 @@ PLUMBED_IN = "ISPLUMBEDIN"
 PRE_INFUSION_SETTINGS = "PREINFUSIONSETTINGS"
 WEEKLY_SCHEDULING_CONFIG = "WEEKLYSCHEDULINGCONFIG"
 BACKFLUSH_ENABLED = "ISBACKFLUSHENABLED"
-
+COFFEE_TEMP = "TEMP_COFFEE"
+STEAM_TEMP = "TEMP_STEAM"
+TANK_LEVEL = "LEVEL_TANK"
